@@ -1,14 +1,13 @@
 requirejs.config({
     paths: {
-        /* Load cogram from local file. On fail, load from CDN. */
+        /* Load cogram from local server. On fail, load from CDN. */
         'cogram': [
+            '//localhost:8080/cogramStatic/cogram_main',
             '//storage.googleapis.com/cogram-public/jupyter-cogram/latest/cogram_main.min',
-            '//localhost:8080/static/cogram_main',
         ],
     },
 });
 
-
 define(['cogram'], function (cogram,) {
     "use strict";
     const logPrefix = '[cogram-sources-loader]';
